@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '2.094003';
+our $VERSION = '2.095000';
 use App::Netdisco::Configuration;
 
 =head1 NAME
@@ -52,7 +52,7 @@ See the demo at: L<https://netdisco2-demo.herokuapp.com/>
 
 =item *
 
-L<Docker images|https://hub.docker.com/r/netdisco/netdisco> are also available
+L<Container images|https://hub.docker.com/r/netdisco/netdisco> are also available
 
 =back
 
